import React, { Suspense } from 'react';
import { Navigate, Route, Routes } from 'react-router-dom';
import Mainlayout from '../layouts/Mainlayout';
import KnowledgeBase from '../pages/KnowledgeBase/KnowledgeBase';
import KnowledgeBaseDetail from '../pages/KnowledgeBase/Detail/KnowledgeBaseDetail';
import Chat from '../pages/Chat/Chat';
import PermissionsPage from '../pages/Permissions/PermissionsPage';
import Loading from '../components/Loading';
import Login from '../pages/Auth/Login';
import Signup from '../pages/Auth/Signup';
import ProtectedRoute from './protectedRoute';
import { useSelector } from 'react-redux';
import NotificationSnackbar from '../components/NotificationSnackbar';

function AppRouter() {
    const { user } = useSelector((state) => state.auth);

    // 检查用户是否有管理权限（leader 或 admin）
    const hasManagePermission = user && (user.role === 'leader' || user.role === 'admin');

    return (
        <Suspense fallback={<Loading />}>
            <NotificationSnackbar />

            <Routes>
                <Route element={<ProtectedRoute />}>
                    <Route
                        path='/'
                        element={
                            <Mainlayout>
                                <KnowledgeBase />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/knowledge-base/:id'
                        element={
                            <Mainlayout>
                                <KnowledgeBaseDetail />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/knowledge-base/:id/:tab'
                        element={
                            <Mainlayout>
                                <KnowledgeBaseDetail />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/chat'
                        element={
                            <Mainlayout>
                                <Chat />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/chat/:knowledgeBaseId'
                        element={
                            <Mainlayout>
                                <Chat />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/chat/:knowledgeBaseId/:chatId'
                        element={
                            <Mainlayout>
                                <Chat />
                            </Mainlayout>
                        }
                    />
                    {/* 权限管理页面路由 - 仅对 leader 或 admin 角色可见 */}
                    <Route
                        path='/permissions'
                        element={
                            <Mainlayout>
                                <PermissionsPage />
                            </Mainlayout>
                        }
                    />
                </Route>
                <Route path='/login' element={<Login />} />
                <Route path='/signup' element={<Signup />} />
                <Route path='*' element={<Navigate to={!!user ? '/' : '/login'} replace />} />
            </Routes>
        </Suspense>
    );
}
export default AppRouter;
